## This concern has +follow+ and +unfollow+ controller actions
## When you use it, be sure that +set_followable+ method is implemented in your controller, otherwise an fatal error will raise.
module FollowableController
  extend ActiveSupport::Concern

  included do
    before_action :authenticate_user!, only: [:follow, :unfollow]
  end

  # POST /v1/users/1/follow
  # POST /v1/users/1/follow.json
  def follow
    if !current_user.following?(followable)
      current_user.follow(followable)
      render status: :created
    else
      render status: :forbidden
    end
  end

  # DELETE /v1/users/1/unfollow
  # DELETE /v1/users/1/unfollow.json
  def unfollow
    if current_user.following?(followable)
      current_user.unfollow(followable)
      render status: :ok
    else
      render status: :forbidden
    end
  end
end
