# == Schema Information
#
# Table name: scores
#
#  id         :integer          not null, primary key
#  name       :string
#  code       :string
#  weight     :float
#  active     :boolean          default("true")
#  created_at :datetime         not null
#  updated_at :datetime         not null
#  score_type :string           default("{}"), is an Array
#

class Score < ApplicationRecord
  has_many :score_user_categories
  has_many :user_categories, through: :score_user_categories

  validates_presence_of :name, :code, :weight, :active
  validates_uniqueness_of :code
  validates_numericality_of :weight

  scope :object_type, ->(name) { where('? = ANY (score_type)', name) }
  has_paper_trail

  def max_value
    score_user_categories.maximum(:value)
  end

  def category_values(category)
    score_user_categories.find { |x| x.score_id == id && x.user_category_id == category.id }.map { |x| [x.code, x.value] }.to_h
  end
end
