module PackageService
  class Link
    def initialize(object)
      @generator = Generator.new(object)
      @cache_key = @generator.cache_key
    end

    def link
      link = retrieve_link

      if link.nil?
        @generator.generate
        link = retrieve_link
      end

      "#{PackageService.dirname}/#{link}" unless link.nil?
    end

    private

    def retrieve_link
      if wait_job
        filename = Rails.cache.fetch(@cache_key)
        return filename if !filename.nil? && File.exist?(PackageService.file_root(filename))

        Rails.cache.delete(@cache_key) if Rails.cache.exist?(@cache_key)
      end

      nil
    end

    def wait_job
      job_key = PackageService.job_key(@cache_key)
      unless Rails.cache.fetch(job_key).nil?
        Timeout.timeout(60) do
          sleep(1.0) until Rails.cache.fetch(job_key).nil? && !Rails.cache.fetch(@cache_key).nil?
        end
      end
      true
    rescue Timeout::Error
      false
    end
  end
end
