require_relative 'boot'

require 'rails'
require 'active_model/railtie'
# require 'active_job/railtie'
require 'active_record/railtie'
require 'action_controller/railtie'
require 'action_mailer/railtie'
require 'action_view/railtie'
# require 'action_cable/engine'
# require 'sprockets/railtie'
require 'rails/test_unit/railtie'

# Require the gems listed in Gemfile, including any gems
# you've limited to :test, :development, or :production.
Bundler.require(*Rails.groups)

module Portalmec
  class Application < Rails::Application
    # Settings in config/environments/* take precedence over those specified here.
    # Application configuration should go into files in config/initializers
    # -- all .rb files in that directory are automatically loaded.

    # Set Time.zone default to the specified zone and make Active Record auto-convert to this zone.
    # Run "rake -D time" for a list of tasks for finding time zone names. Default is UTC.
    # config.time_zone = 'Central Time (US & Canada)'

    # The default locale is :en and all translations from config/locales/*.rb,yml are auto loaded.
    # config.i18n.load_path += Dir[Rails.root.join('my', 'locales', '*.{rb,yml}').to_s]
    # config.i18n.default_locale = :de

    # Do not swallow errors in after_commit/after_rollback callbacks.
    config.active_record.raise_in_transactional_callbacks = true

    # loading lib files
    config.autoload_paths << Rails.root.join('lib')
    config.autoload_paths << Rails.root.join('app/builders')

    config.eager_load_paths += Dir["#{Rails.root}/lib/**/"]

    # protection against attacks
    config.middleware.use Rack::Attack

    # CORS for login via rest
    # config.middleware.use Rack::Cors do
    # config.middleware.insert_before 0, "Rack::Cors", :debug => true, :logger => (-> { Rails.logger }) do
    #   allow do
    #     origins '*'
    #     # TODO: change when mobile app is done
    #     resource '/auth/*',
    #       headers: :any,
    #       expose: ['access-token', 'expiry', 'token-type', 'uid', 'client'],
    #       methods: [:get, :post, :options, :delete, :put]
    #   end
    # end

    config.middleware.use Rack::Cors do
      allow do
        origins '*'
        resource '*',
                 :headers => :any,
                 :expose => ['access-token', 'expiry', 'token-type', 'uid', 'client', 'x-total-count'],
                 :methods => [:get, :post, :options, :delete, :put]
      end
    end


    # default language
    config.i18n.default_locale = 'pt-BR'.to_sym

    # active job
    config.active_job.queue_adapter = :sidekiq

    # api mode
    config.api_only = true

    #TODO fix ugly code when omniauth is fixed
    # Only loads a smaller set of middleware suitable for API only apps.
    # Middleware like session, flash, cookies can be added back manually.
    # Skip views, helpers and assets when generating a new resource.
    config.middleware.use ActionDispatch::Flash
    config.middleware.use ActionDispatch::Cookies
    config.middleware.use ActionDispatch::Session::CookieStore

  end
end
