require 'mimemagic'

##
# This abstract class representes the interface to generate thumbnails
module Thumbnail
  class GeneratableStrategy

    ##
    # Generate a thumbnail based on the +media+
    # +media+ needs to be a pointer to a file
    def generate(media)
      raise NotImplementedError
    end

    ##
    # Checks if the strategy can generate a thumbnail of that +media+
    def can_generate?(media)
      if File == media.class
        mime = MimeMagic.by_magic(media)
        return mime.type.include? yield unless mime.blank?
      end
      false
    end

  end
end
