require 'acceptance_helpers'

resource 'Learning Objects' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  before { 12.times { create(:learning_object) } }

  let(:learning_objects) { LearningObject.all }

  get '/v1/learning_objects' do
    parameter :limit, 'Limit of learning objects'
    parameter :offset, 'Offset of learning objects'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of learning objects' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(LearningObject.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/learning_objects/:id' do
    let(:id) { learning_objects.first.id }

    example 'Get a learning object' do
      do_request
      expect(path).to eq("/v1/learning_objects/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(LearningObject.find(id)))
      expect(status).to eq(200)
    end
  end

  #
  # head "/orders" do
  #   example_request "Getting the headers" do
  #     expect(response_headers["Cache-Control"]).to eq("max-age=0, private, must-revalidate")
  #   end
  # end
  #
  # post "/orders" do
  #   parameter :name, "Name of order", :required => true, :scope => :order
  #   parameter :paid, "If the order has been paid for", :required => true, :scope => :order
  #   parameter :email, "Email of user that placed the order", :scope => :order
  #
  #   response_field :name, "Name of order", :scope => :order, "Type" => "String"
  #   response_field :paid, "If the order has been paid for", :scope => :order, "Type" => "Boolean"
  #   response_field :email, "Email of user that placed the order", :scope => :order, "Type" => "String"
  #
  #   let(:name) { "Order 1" }
  #   let(:paid) { true }
  #   let(:email) { "email@example.com" }
  #
  #   let(:raw_post) { params.to_json }
  #
  #   example_request "Creating an order" do
  #     explanation "First, create an order, then make a later request to get it back"
  #
  #     order = JSON.parse(response_body)
  #     expect(order.except("id", "created_at", "updated_at")).to eq({
  #       "name" => name,
  #       "paid" => paid,
  #       "email" => email,
  #     })
  #     expect(status).to eq(201)
  #
  #     client.get(URI.parse(response_headers["location"]).path, {}, headers)
  #     expect(status).to eq(200)
  #   end
  # end
  #
  # get "/orders/:id" do
  #   let(:id) { order.id }
  #
  #   example_request "Getting a specific order" do
  #     expect(response_body).to eq(order.to_json)
  #     expect(status).to eq(200)
  #   end
  # end
  #
  # put "/orders/:id" do
  #   parameter :name, "Name of order", :scope => :order
  #   parameter :paid, "If the order has been paid for", :scope => :order
  #   parameter :email, "Email of user that placed the order", :scope => :order
  #
  #   let(:id) { order.id }
  #   let(:name) { "Updated Name" }
  #
  #   let(:raw_post) { params.to_json }
  #
  #   example_request "Updating an order" do
  #     expect(status).to eq(204)
  #   end
  # end
  #
  # delete "/orders/:id" do
  #   let(:id) { order.id }
  #
  #   example_request "Deleting an order" do
  #     expect(status).to eq(204)
  #   end
  # end
end
